==> assertive_0.2-6.tar.gz: assertive/R/assert-r-has-capability.R <==
#' @rdname r_can_find_tools
#' @export
assert_r_can_find_tools <- function()
{
  assert_engine(predicate = r_can_find_tools)
}

#' @rdname r_can_find_tools
#' @export
assert_r_can_compile_code <- function()
{
  assert_engine(predicate = r_can_compile_code)
}

#' @rdname r_can_find_tools
#' @export
assert_r_can_build_translations <- function()
{
  assert_engine(predicate = r_can_build_translations)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_jpeg_capability <- function()
{
  assert_engine(predicate = r_has_jpeg_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_png_capability <- function()
{
  assert_engine(predicate = r_has_png_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_tiff_capability <- function()
{
  assert_engine(predicate = r_has_tiff_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_tcltk_capability <- function()
{
  assert_engine(predicate = r_has_tcltk_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_x11_capability <- function()
{
  assert_engine(predicate = r_has_x11_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_aqua_capability <- function()
{
  assert_engine(predicate = r_has_aqua_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_http_ftp_capability <- function()
{
  assert_engine(predicate = r_has_http_ftp_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_sockets_capability <- function()
{
  assert_engine(predicate = r_has_sockets_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_libxml_capability <- function()
{
  assert_engine(predicate = r_has_libxml_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_fifo_capability <- function()
{
  assert_engine(predicate = r_has_fifo_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_cledit_capability <- function()
{
  assert_engine(predicate = r_has_cledit_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_iconv_capability <- function()
{
  assert_engine(predicate = r_has_iconv_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_nls_capability <- function()
{
  assert_engine(predicate = r_has_nls_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_profmem_capability <- function()
{
  assert_engine(predicate = r_has_profmem_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_cairo_capability <- function()
{
  assert_engine(predicate = r_has_cairo_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_icu_capability <- function()
{
  assert_engine(predicate = r_has_icu_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_long_double_capability <- function()
{
  assert_engine(predicate = r_has_long_double_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_libcurl_capability <- function()
{
  assert_engine(predicate = r_has_libcurl_capability)
}

==> assertive_0.3-0.tar.gz: assertive/R/assert-r-has-capability.R <==
#' @rdname r_can_find_tools
#' @export
assert_r_can_find_tools <- function()
{
  assert_engine(r_can_find_tools)
}

#' @rdname r_can_find_tools
#' @export
assert_r_can_compile_code <- function()
{
  assert_engine(r_can_compile_code)
}

#' @rdname r_can_find_tools
#' @export
assert_r_can_build_translations <- function()
{
  assert_engine(r_can_build_translations)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_jpeg_capability <- function()
{
  assert_engine(r_has_jpeg_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_png_capability <- function()
{
  assert_engine(r_has_png_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_tiff_capability <- function()
{
  assert_engine(r_has_tiff_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_tcltk_capability <- function()
{
  assert_engine(r_has_tcltk_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_x11_capability <- function()
{
  assert_engine(r_has_x11_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_aqua_capability <- function()
{
  assert_engine(r_has_aqua_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_http_ftp_capability <- function()
{
  assert_engine(r_has_http_ftp_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_sockets_capability <- function()
{
  assert_engine(r_has_sockets_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_libxml_capability <- function()
{
  assert_engine(r_has_libxml_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_fifo_capability <- function()
{
  assert_engine(r_has_fifo_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_cledit_capability <- function()
{
  assert_engine(r_has_cledit_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_iconv_capability <- function()
{
  assert_engine(r_has_iconv_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_nls_capability <- function()
{
  assert_engine(r_has_nls_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_profmem_capability <- function()
{
  assert_engine(r_has_profmem_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_cairo_capability <- function()
{
  assert_engine(r_has_cairo_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_icu_capability <- function()
{
  assert_engine(r_has_icu_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_long_double_capability <- function()
{
  assert_engine(r_has_long_double_capability)
}

#' @rdname r_has_jpeg_capability
#' @export
assert_r_has_libcurl_capability <- function()
{
  assert_engine(r_has_libcurl_capability)
}
